pynrc.reduce.ref\_pixels.NRC\_refs
==================================

.. currentmodule:: pynrc.reduce.ref_pixels

.. autoclass:: NRC_refs
   :members:
   :inherited-members:
   :show-inheritance:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~NRC_refs.__init__
      ~NRC_refs.calc_avg_amps
      ~NRC_refs.calc_avg_cols
      ~NRC_refs.calc_col_smooth
      ~NRC_refs.correct_amp_refs
      ~NRC_refs.correct_col_refs
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~NRC_refs.mask_act
      ~NRC_refs.mask_channels
      ~NRC_refs.mask_ref
      ~NRC_refs.multiaccum
      ~NRC_refs.multiaccum_times
      ~NRC_refs.refs_bot
      ~NRC_refs.refs_left
      ~NRC_refs.refs_right
      ~NRC_refs.refs_top
   
   